Attribute VB_Name = "GlobalUtilities"
Attribute VB_Description = "Global Definitions"
'This module contains global data declarations and generally handy routines
'used by most of the modules

'Case insensitive comparisons in all work
Option Compare Text

'Require declaration of all variables before use
Option Explicit


'Constant to store a carriage return. Declared in Declare Variables
Public Const strNewLine = vbCrLf

'Constant
Public Const strDBPathNotSet = ""

'Constants for currency Formating
Public Const moneyOmitSign = True
Public Const moneyDontOmitSign = False
Public Const moneyExcludeType = True
Public Const moneyDontExcludeType = False

'Variables to store the currently running batch printing job
Public lngBatchPrintJobType As Long
Public Const lngDepositJob = 0
Public Const lngLevyJob = 1

'Constant for maximum file size for text boxes
Public Const sysMaxFileSize = 32000

'Constants for registry Access
Public Const regAppName = "MPHS Levy System"
Public Const regSection = "System"
Public Const regKeyAdminPassword = "Security"
Public Const regKeyDBPath = "DBPath"


Public Function Tabs(Number_reqd As Long) As String
    'Returns a string containing the requested number of Tab characters
    Dim lngCounter As Long
    
    For lngCounter = 1 To Number_reqd
        Tabs = Tabs & Chr(9)
    Next

End Function


Public Function IsMultipleOf(Divident As Variant, Divisor As Long) As Boolean
    'Checks if the divident is a multiple of the divisor by comparing the results
    'of fractional and integer division
    If (Divident \ Divisor) = (Divident / Divisor) Then
        IsMultipleOf = True
    Else
        IsMultipleOf = False
    End If

End Function


Public Function TextTheSame(Text1 As String, Text2 As String) As Boolean
    'Perform a case insensitive search by first converting both strings to upper case and
    'then comparing the results with the traditional binary compare.
    
    If UCase(Trim(Text1)) = UCase(Trim(Text2)) Then
        TextTheSame = True
    Else
        TextTheSame = False
    End If

End Function


Public Function CurrencyFormat(ByVal Amount As Currency, Optional reqOmitSign As Boolean, Optional reqExcludeType As Boolean) As String
    'Default format includes both the sign and type
    'Custom routine for formating the currency data type
        
    Dim FractionPart As Single
    Dim IntegerPart As Long
    Dim FormatedText As String
    
    'If either of the optional parameters is missing then assume default behaviour
    If IsMissing(reqOmitSign) Then reqOmitSign = False
    If IsMissing(reqExcludeType) Then reqExcludeType = False
    
    'separate the amount into Dollars and cents
    IntegerPart = Int(Abs(Amount))
    FractionPart = Abs(Amount) - IntegerPart
    
    'Do the format
    If reqOmitSign Then
        FormatedText = Format(IntegerPart, "@@@ @@@ @@@") _
                      & Format(FractionPart, ".00")
    Else
            FormatedText = Format(IntegerPart, "$ @@@ @@@ @@@") _
                      & Format(FractionPart, ".00")
    End If
    
    'Include the type if required in traditional accounting balance format
    If Not (reqExcludeType) Then
        If Amount < 0 Then
            FormatedText = FormatedText & " DR"
        Else
            FormatedText = FormatedText & " CR"
        End If
    End If
    
    CurrencyFormat = FormatedText
    
End Function

Public Sub ClearAllTextboxes(objForm As Form)
    Dim objControl As Control
    
    For Each objControl In objForm.Controls
        If TypeOf objControl Is TextBox Then
            objControl.Text = ""
        End If
    Next
    
End Sub

Public Sub TrimContentsOfAllTextBoxes(objForm As Form)
    'Removes all leading and trailing spaces in all the textbox controls
    
    Dim objControl As Control
    
    For Each objControl In objForm.Controls
        If TypeOf objControl Is TextBox Then
            objControl.Text = Trim(objControl.Text)
        End If
    Next
    
End Sub

Public Sub UnloadAllChildForms(objParent As Form)
    Dim objForm As Form
    For Each objForm In Forms
        If objForm.Name <> objParent.Name Then
            Unload objForm
        End If
    Next
End Sub
